<?php

    /**
     * Form on user edit page
     * @param $FH FormHandler of the page
     * @param $mode add or edit mode
    **/
    function _asterisk_baseEdit($FH, $mode) {
        $f = new DivForModule(_T("Asterisk properties", "asterisk"), "#fff3ee");

        // Show plugin details by default
        $show = true;

        // Show asterisk voicemail details
        $show_voicemail = true;

        // User has not asterisk attributes by default
        $hasAsterisk = false;

        // User is not disabled by default
        $disabledAsterisk = false;

        $uid = "";
        $phone_number_value = "";
        $voicemail = "";
        $voicemail_password = "";

        if ($mode == "edit") {
            // check user actual values
            $uid = $FH->getArrayOrPostValue('uid');

            if (hasObjectClass($uid)) {
                $hasAsterisk = true;
                $phone_number_value = getPhoneNumber($uid);

                if(hasVoicemail($uid)) {
                	$show_voicemail = true;

                	$voicemail_attributes = getVoicemailAttributes($uid);

                	$voicemail = $voicemail_attributes[0];
                	$voicemail_password = $voicemail_attributes[1];
                }


                else
                	$show_voicemail = false;
            }
            else {
                $show = false;
                $show_voicemail = false;
            }
        }

        if ($mode == "add" && $FH->getValue('asterisk_access') == 'off')
            $show = false;

        $f->push(new Table());
        $f->add(
            new TrFormElement(_T("Asterisk access", "asterisk"), new CheckboxTpl("asterisk_access")),
                array("value"=> $show ? "checked": "", "extraArg"=>'onclick="toggleVisibility(\'asterisk_div\');"')
        );
        $f->pop();

        $asterisk_div = new Div(array("id" => "asterisk_div"));
        $asterisk_div->setVisibility($show);
        $f->push($asterisk_div);
        $f->push(new Table());

        $f->add(
            new TrFormElement(_T("Phone number", "asterisk"), new InputTpl("phone_number")),
                array("value" => $phone_number_value, "placeholder" => "1234",
                      "maxlength" => 10)
        );

        // This field is required only when phone number change
        $f->add(
            new TrFormElement(_T("Phone password", "asterisk"), new InputTpl("phone_password")),
                array("value" => "")
        );
        $f->pop();

        $f->push(new Table());
        $f->add(
        		new TrFormElement(_T("Asterisk voicemail", "asterisk"), new CheckboxTpl("asterisk_voicemail")),
        		array("value"=> $show_voicemail ? "checked": "", "extraArg"=>'onclick="toggleVisibility(\'asterisk_voicemail_div\');"')
        );
        $f->pop();

        $asterisk_voicemail_div = new Div(array('id' => 'asterisk_voicemail_div'));
        $asterisk_voicemail_div->setVisibility($show_voicemail);

        $f->push($asterisk_voicemail_div);
        $f->push(new Table());

        $f->add(
        		new TrFormElement(_T("Voicemail", "asterisk"), new InputTpl("voicemail")),
        		array("value" => $voicemail, "placeholder" => "user@domain.com")
        );

        $f->add(
        		new TrFormElement(_T("Voicemail password", "asterisk"), new InputTpl("voicemail_password")),
        		array("value" => $voicemail_password)
        );

        $f->pop();
        $f->pop();
        $f->pop();

        return $f;
    }

    /**
     * Function called before changing user attributes
     * @param $FH FormHandler of the page
     * @param $mode add or edit mode
     */
    function _asterisk_verifInfo($FH, $mode) {
        global $error;

        $asterisk_errors = "";

        if ($FH->getPostValue("asterisk_access") == "on") {
            if ($FH->getPostValue('phone_number') != "") {
                $phone_reg = '/([0-9])/';

                if (!preg_match($phone_reg, $FH->getPostValue('phone_number'), $matches)) {
                    $asterisk_errors .= _T("You must specify a valid phone number.","asterisk")."<br />";
                    setFormError("asterisk");
                }
            }
        }

        $error .= $asterisk_errors;

        return $asterisk_errors ? 1 : 0;
    }


    /**
     * Function called for changing user attributes
     * @param $FH FormHandler of the page
     * @param $mode add or edit mode
     */
    function _asterisk_changeUser($FH, $mode) {
        global $result;
        $uid = $FH->getPostValue('uid');

        // Asterisk checkbox is checked
        if ($FH->getPostValue("asterisk_access") == "on") {
        	$phone_number = $FH->getPostValue('phone_number');
        	$phone_password = $FH->getPostValue('phone_password');

        	if($phone_password == '')
        		$phone_password = $phone_number;

            if ($mode == "edit") {

                if (hasObjectClass($uid)) {
                    $old_phone_number = getPhoneNumber($uid);

                    // and phone_number not the same as AstAccountCallerID
                    if ($phone_number != $old_phone_number) {
                        updatePhoneNumber($uid, $phone_number);
                        updatePhonePassword($uid, $phone_password);

                        if (!isXMLRPCError())
                            $result .= _T("Asterisk phone attributes updated.", "asterisk")."<br />";
                    }

                    if ($FH->getPostValue("asterisk_voicemail") == "on") {
                    	$voicemail = $FH->getPostValue('voicemail');
                    	$voicemail_password = $FH->getPostValue('voicemail_password');

                    	if($voicemail_password == '')
                    		$voicemail_password = $phone_number;

                    	if (hasVoicemail($uid)) {
                    		$voicemail_attributes = getVoicemailAttributes($uid);

                    		$old_voicemail = $voicemail_attributes[0];

                    		if ($voicemail == $old_voicemail)
                    			$voicemail = $old_voicemail;

                    		if ($voicemail != '' && $voicemail_password != '') {
                    			updateVoicemail($uid, $phone_number, $voicemail, $voicemail_password);

                                if (!isXMLRPCError())
                    			    $result .= _T("Asterisk voicemail attributes updated.", "asterisk")."<br />";
                    		}
                    	}

                    	else {
                    		if ($voicemail != '' && $voicemail_password != '') {
                    			updateVoicemail($uid, $phone_number, $voicemail, $voicemail_password);

                                if (!isXMLRPCError())
                    			    $result .= _T("Asterisk voicemail attributes added.", "asterisk")."<br />";
                    		}
                    	}
                    }

                    else {
                    	if (hasVoicemail($uid)) {
                    		updateVoicemail($uid, "", "", "");

                            if (!isXMLRPCError())
                    		    $result .= _T("Asterisk voicemail attributes removed.", "asterisk")."<br />";
                    	}
                    }
                }
                // If user doesn't have asterisk objectClass
                else {
                    addObjectClass($uid);
                    updatePhoneNumber($uid, $phone_number);
                    updatePhonePassword($uid, $phone_password);

                    if (!isXMLRPCError())
                        $result .= _T("Asterisk phone attributes added.", "asterisk")."<br />";

                    if ($FH->getPostValue("voicemail_access") == "on") {
                    	if ($voicemail != '' && $voicemail_password != '') {
                    		updateVoicemail($uid, $phone_number, $voicemail, $voicemail_password);

                            if (!isXMLRPCError())
                    		    $result .= _T("Asterisk voicemail attributes added.", "asterisk")."<br />";
                    	}
                    }
                }
            }

            else {
                addObjectClass($uid);
                updatePhoneNumber($uid, $phone_number);
                updatePhonePassword($uid, $phone_password);

                if (!isXMLRPCError())
                    $result .= _T("Asterisk phone attributes added.", "asterisk")."<br />";

                if ($FH->getPostValue("asterisk_voicemail") == "on") {
                	// If voicemail not empty
                	if ($FH->getPostValue('voicemail') != '' && $FH->getPostValue('voicemail_password') != '') {
                		updateVoicemail($uid, $phone_number, $FH->getPostValue('voicemail'), $FH->getPostValue('voicemail_password'));

                        if (!isXMLRPCError())
                		    $result .= _T("Asterisk voicemail attributes added.", "asterisk")."<br />";
                	}
                }
            }
        }

        // Asterisk checkbox isn't checked
        else {
            if ($mode == "edit") {
                if (hasObjectClass($uid)) {
                    // If voicemail not empty
                    if (hasVoicemail($uid)) {
                        updateVoicemail($uid, "", "", "");

                        if (!isXMLRPCError())
                            $result .= _T("Asterisk voicemail attributes removed.", "asterisk")."<br />";
                    }

                    updatePhoneNumber($uid, "");
                    updatePhonePassword($uid, "");
                    delObjectClass($uid);

                    if (!isXMLRPCError())
                        $result .= _T("Asterisk phone attributes removed.", "asterisk")."<br />";
                }
            }
        }

        return 0;
    }
?>
